@@ -1,14 +1,14 @@
 """
 Type annotations for forecast service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/literals.html)
+[Open documentation](./literals.md)
 
 Usage::
 
     ```python
-    from mypy_boto3_forecast.literals import AttributeType
+    from mypy_boto3_forecast.literals import AttributeTypeType
 
-    data: AttributeType = "float"
+    data: AttributeTypeType = "float"
     ```
 """
 import sys
@@ -20,12 +20,12 @@ else:
 
 
 __all__ = (
-    "AttributeType",
-    "DatasetType",
-    "Domain",
-    "EvaluationType",
-    "FeaturizationMethodName",
-    "FilterConditionString",
+    "AttributeTypeType",
+    "DatasetTypeType",
+    "DomainType",
+    "EvaluationTypeType",
+    "FeaturizationMethodNameType",
+    "FilterConditionStringType",
     "ListDatasetGroupsPaginatorName",
     "ListDatasetImportJobsPaginatorName",
     "ListDatasetsPaginatorName",
@@ -33,18 +33,18 @@ __all__ = (
     "ListForecastsPaginatorName",
     "ListPredictorBacktestExportJobsPaginatorName",
     "ListPredictorsPaginatorName",
-    "ScalingType",
+    "ScalingTypeType",
 )
 
 
-AttributeType = Literal["float", "geolocation", "integer", "string", "timestamp"]
-DatasetType = Literal["ITEM_METADATA", "RELATED_TIME_SERIES", "TARGET_TIME_SERIES"]
-Domain = Literal[
+AttributeTypeType = Literal["float", "geolocation", "integer", "string", "timestamp"]
+DatasetTypeType = Literal["ITEM_METADATA", "RELATED_TIME_SERIES", "TARGET_TIME_SERIES"]
+DomainType = Literal[
     "CUSTOM", "EC2_CAPACITY", "INVENTORY_PLANNING", "METRICS", "RETAIL", "WEB_TRAFFIC", "WORK_FORCE"
 ]
-EvaluationType = Literal["COMPUTED", "SUMMARY"]
-FeaturizationMethodName = Literal["filling"]
-FilterConditionString = Literal["IS", "IS_NOT"]
+EvaluationTypeType = Literal["COMPUTED", "SUMMARY"]
+FeaturizationMethodNameType = Literal["filling"]
+FilterConditionStringType = Literal["IS", "IS_NOT"]
 ListDatasetGroupsPaginatorName = Literal["list_dataset_groups"]
 ListDatasetImportJobsPaginatorName = Literal["list_dataset_import_jobs"]
 ListDatasetsPaginatorName = Literal["list_datasets"]
@@ -52,4 +52,4 @@ ListForecastExportJobsPaginatorName = Literal["list_forecast_export_jobs"]
 ListForecastsPaginatorName = Literal["list_forecasts"]
 ListPredictorBacktestExportJobsPaginatorName = Literal["list_predictor_backtest_export_jobs"]
 ListPredictorsPaginatorName = Literal["list_predictors"]
-ScalingType = Literal["Auto", "Linear", "Logarithmic", "ReverseLogarithmic"]
+ScalingTypeType = Literal["Auto", "Linear", "Logarithmic", "ReverseLogarithmic"]
