@@ -751,6 +751,10 @@ StatisticsTypeDef = TypedDict(
         "Max": str,
         "Avg": float,
         "Stddev": float,
+        "CountLong": int,
+        "CountDistinctLong": int,
+        "CountNullLong": int,
+        "CountNanLong": int,
     },
     total=False,
 )
